"""Provide a main module."""


def add(n_1: int, n_2: int) -> int:
    """Provide a dummy function."""
    return n_1 + n_2
